from distutils.core import setup

setup(
    name = 'meucalebe',
    version = '1.5.0',
    py_modules = ['meucalebe'],
    author = 'calebe',
    author_email = 'calebebastos21@gmail.com',
    url = '',
    description = 'Apenas teste'
    )
